@@ -13,7 +13,7 @@
 ##############################################################################
 """Stateful content workflow manager.
 
-$Id: test_contentworkflow.py 85791 2008-04-27 18:40:59Z lgs $
+$Id: test_contentworkflow.py 95456 2009-01-29 17:55:54Z wosc $
 """
 import unittest
 
@@ -25,7 +25,7 @@ from zope.lifecycleevent import ObjectCreatedEvent
 from zope.lifecycleevent.interfaces import IObjectCreatedEvent
 from zope.traversing.api import traverse
 
-from zope.app.container.contained import Contained
+from zope.container.contained import Contained
 
 from zope.app.workflow.interfaces import IProcessDefinition
 from zope.app.workflow.interfaces import IProcessInstanceContainerAdaptable
