@@ -13,11 +13,12 @@
 ##############################################################################
 """Setup for Placeful Worfklow Tests
 
-$Id: workflowsetup.py 70211 2006-09-17 14:45:07Z flox $
+$Id: workflowsetup.py 95196 2009-01-27 14:04:30Z thefunny42 $
 """
+from zope.component import getGlobalSiteManager
 from zope.interface import implements
+from zope.traversing.api import traverse
 
-from zope.app import zapi
 from zope.app.security.principalregistry import principalRegistry
 from zope.app.component.testing import PlacefulSetup
 from zope.app.testing import setup
@@ -26,12 +27,8 @@ from zope.app.testing import setup
 class WorkflowSetup(PlacefulSetup):
 
     def setUp(self):
-        self.root_sm = zapi.getGlobalSiteManager()
+        self.root_sm = getGlobalSiteManager()
 
         self.sm = PlacefulSetup.setUp(self, site=True)
-        self.default = zapi.traverse(self.sm, "default")
-        self.cm = self.default.registrationManager
+        self.default = traverse(self.sm, "default")
 
-        self.sm1 = self.makeSite('folder1')
-        self.default1 = zapi.traverse(self.sm1, "default")
-        self.cm1 = self.default1.registrationManager
